!    This program is to plot the time variation of the flux at 800 km 
!    provided by the FLIP model in both hemispheres
!    3/10/2015 by Yan Wang
Program main
    
    implicit none

    integer, parameter:: num=100,nc=101,JMAX=399,nstep=15,dt=90,zb=800
    integer:: jbn,jbs,ns,jbg
    integer nst,LNBLNK,i,j,k,h
    character suff*6
    CHARACTER*256 :: WORKDIR  

    real(8),dimension(JMAX):: Z,GL,Te,TO,TH,NO,NH,NHE,XIONN,Ne
    real(8),dimension(JMAX):: UO,UH,UHE,XIONV,Ue            
      
    real(8) M_O,Re,ak,pi,M_H,M_He,vzmax,vfO,vfH,vfHe
    real(8), external :: ERRORF
    real(8),dimension(2) :: Fden_O,Fden_H,Fden_He,FV_O,FV_H,FV_He
    real(8),dimension(2) :: FT_O,FT_H,FT_He,FT_e,VtppO,VtppH,VtppHe
    real(8),dimension(2) :: VtprO,VtprH,VtprHe,factorO,factorH,factorHe
    real(8),dimension(2) :: fmaxO,fmaxH,fmaxHe,bottom_upO,bottom_upH,bottom_upHe

    data M_O/2.65676233d-26/,M_H/1.67382304d-27/,M_He/6.69529216d-27/
    data Re/6371.2d3/,ak/1.38065d-23/,pi/3.1415926d0/
! Get WORKDIR of current working directory
   CALL GETCWD(WORKDIR)
   OPEN(201,file='Boundary_flux.dat',status='unknown')  
   
   do i=1,nstep
          nst=(i-1)*dt
          write(suff,'(i6)') nst
          suff=adjustl(suff)
          
          if(i==1) then          
             open(25,file=WORKDIR(:LNBLNK(WORKDIR))//'/PLOT/FLIP25gsk.1',status='old') 
          else
             open(25,file=WORKDIR(:LNBLNK(WORKDIR))//'/PLOT/FLIP25gsk.'//suff(:LNBLNK(suff)), &
                    status='old')
          endif    

     !  Read from FLIP results
          Read(25,'(A)')
          Read(25,'(A)')
          DO J=1,JMAX
                 read(25,861) k,Z(J),GL(J),Te(J),TO(J),TH(J),NO(J),NH(J),NHe(J),&
                                 XIONN(J),Ne(J),UO(J),UH(J),UHE(J),XIONV(J)
          ENDDO
          CLOSE(25)
 861  FORMAT(I4,1p,14E15.6)   

          do j=1,JMAX/2
             if(Z(j).ge.zb) then
                jbn=j-1
                exit
             endif
          enddo
          do j=JMAX,JMAX/2,-1
             if(Z(j).ge.zb) then
                jbs=j+1
                exit
            endif
          enddo   

          ns=1
          jbg=jbn     
          Fden_O(ns) = NO(jbg)
          Fden_H(ns) = NH(jbg)
          Fden_He(ns)= NHe(jbg)
          FV_O(ns)   = UO(jbg)
          FV_H(ns)   = UH(jbg)
          FV_He(ns)  = UHe(jbg)
          FT_O(ns)   = TO(jbg)
          FT_H(ns)   = TH(jbg)
          FT_He(ns)  = TO(jbg)       
          FT_e(ns)   = Te(jbg)          

          ns=2
          jbg=jbs     
          Fden_O(ns) = NO(jbg)
          Fden_H(ns) = NH(jbg)
          Fden_He(ns)= NHe(jbg)
          FV_O(ns)   = -1.0*UO(jbg)
          FV_H(ns)   =  -1.0*UH(jbg)
          FV_He(ns)  =  -1.0*UHe(jbg)
          FT_O(ns)   = TO(jbg)
          FT_H(ns)   = TH(jbg)
          FT_He(ns)  = TO(jbg)       
          FT_e(ns)   = Te(jbg)        

          do ns=1,2
               !  perpendicular oxygen/Hydrog thermal velocity (in Re/s)
               VtppO(ns)=sqrt(2.0d0*ak*FT_O(ns)/M_O)/Re
               VtppH(ns)=sqrt(2.0d0*ak*FT_H(ns)/M_H)/Re
               VtppHe(ns)=sqrt(2.0d0*ak*FT_He(ns)/M_He)/Re

               !  parallel thermal velocity (in Re/s)
               VtprO(ns)=VtppO(ns)
               VtprH(ns)=VtppH(ns)
               VtprHe(ns)=VtppHe(ns)

               !  Convert O+ and H+ bulk velocity of injected distribution to Re/s
               FV_O(ns)=FV_O(ns)/Re
               FV_H(ns)=FV_H(ns)/Re
               FV_He(ns)=FV_He(ns)/Re     

!-------------
!  factorO(H): maxm parallel velocity (relative to average velocity)
!              allowed for injected particles
!  vaxmaxO(H): parallel velocity at vpar*f(vpar) = maxm
!  fmaxO(H): maxm value of vpar*f(vpar)
!-------------

               factorO(ns)=VtprO(ns)*10.0d0
               vzmax=(FV_O(ns)+sqrt(FV_O(ns)**2+2.0d0*VtprO(ns)**2))/2.0d0
               fmaxO(ns)=vzmax*exp(-((vzmax-FV_O(ns))/VtprO(ns))**2)

               factorH(ns)=VtprH(ns)*5.0d0
               vzmax=(FV_H(ns)+sqrt(FV_H(ns)**2+2.0d0*VtprH(ns)**2))/2.0d0
               fmaxH(ns)=vzmax*exp(-((vzmax-FV_H(ns))/VtprH(ns))**2)

               factorHe(ns)=VtprHe(ns)*5.0d0
               vzmax=(FV_He(ns)+sqrt(FV_He(ns)**2+2.0d0*VtprHe(ns)**2))/2.0d0
               fmaxHe(ns)=vzmax*exp(-((vzmax-FV_He(ns))/VtprHe(ns))**2)

               vfO=0.5d0*(VtprO(ns)*exp(-(FV_O(ns)/VtprO(ns))**2)/sqrt(pi)+ &
                       FV_O(ns)*(1.0d0+ERRORF(FV_O(ns)/VtprO(ns))))
               vfH=0.5d0*(VtprH(ns)*exp(-(FV_H(ns)/VtprH(ns))**2)/sqrt(pi)+ &
                       FV_H(ns)*(1.0d0+ERRORF(FV_H(ns)/VtprH(ns))))
               vfHe=0.5d0*(VtprHe(ns)*exp(-(FV_He(ns)/VtprHe(ns))**2)/sqrt(pi)+ &
                         FV_He(ns)*(1.0d0+ERRORF(FV_He(ns)/VtprHe(ns))))

! area in m^-2, Re in m, density in cm^-3

               bottom_upO(ns)=1.0e6*Fden_O(ns)*vfO*Re
               bottom_upH(ns)=1.0e6*Fden_H(ns)*vfH*Re
               bottom_upHe(ns)=1.0e6*Fden_He(ns)*vfHe*Re 
          enddo

          WRITE(201,'(I3,6es14.5)') i-1,bottom_upO(1),bottom_upO(2),bottom_upH(1),&
                                                    bottom_upH(2),bottom_upHe(1),bottom_upHe(2)

    enddo
    CLOSE(201)      

END Program                    

!-----------------------------------------------------------------------
!  Error function
!-----------------------------------------------------------------------
real(8) function ERRORF(x)
    real(8), intent(in):: x
    real(8) :: pi

    data pi/3.1415926540d0/

    ERRORF=2.0d0*(x-x**3/3.0d0+x**5/10.0d0-x**7/42.0d0+x**9/216.0d0)/SQRT(pi)

end function  
