clear all
load Den_GSK30.dat
load Vel_GSK30.dat
load Tpr_GSK30.dat
load Tpp_GSK30.dat

load MLAT_GSK30.dat
load ALT_GSK30.dat
load sg_GSK30.dat
load bfd_GSK30.dat
load EFD_GSK30.dat

num=121;
nstep=145;
UT=[0:0.5:72];
UT=UT';

sg=sg_GSK30;       %  in Re
bfd=bfd_GSK30;     %  in Tesla
MLAT=MLAT_GSK30;
ALT=ALT_GSK30;

Den=Den_GSK30;
Vel=Vel_GSK30;
Tpr=Tpr_GSK30;
Tpp=Tpp_GSK30;
EFD=EFD_GSK30;

% density in cm^-3
NO=reshape(Den(:,1),num,nstep);
NO=NO';

NH=reshape(Den(:,2),num,nstep);
NH=NH';

NHe=reshape(Den(:,3),num,nstep);
NHe=NHe';

Ne=reshape(Den(:,4),num,nstep);
Ne=Ne';

% Parallel temperature 
TprO=reshape(Tpr(:,1),num,nstep);
TprO=TprO';

TprH=reshape(Tpr(:,2),num,nstep);
TprH=TprH';

TprHe=reshape(Tpr(:,3),num,nstep);
TprHe=TprHe';

Tpre=reshape(Tpr(:,4),num,nstep);
Tpre=Tpre';

% Perpendicular temperature 
TppO=reshape(Tpp(:,1),num,nstep);
TppO=TppO';

TppH=reshape(Tpp(:,2),num,nstep);
TppH=TppH';

TppHe=reshape(Tpp(:,3),num,nstep);
TppHe=TppHe';

Tppe=reshape(Tpp(:,4),num,nstep);
Tppe=Tppe';

% velocity in m/s
VO=reshape(Vel(:,1),num,nstep);
VO=VO';

VH=reshape(Vel(:,2),num,nstep);
VH=VH';

VHe=reshape(Vel(:,3),num,nstep);
VHe=VHe';

Ve=reshape(Vel(:,4),num,nstep);
Ve=Ve';

% electric field
efield=reshape(EFD(:,1),num,nstep);
efield=efield';
efield=efield.*1e+7;
% electric potential
poten=reshape(EFD(:,2),num,nstep);
poten=poten';
poten=poten.*1e7;

% latitude at r=1.3 Re
la=acos(sqrt(1.3/4.0))*180.0/pi;
x1(1:121)=la;
x2(1:121)=-la;

% H+
y=NH;
z1=logspace(-1,4,121);
subplot(3,1,1)
plot(MLAT,y(2,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT,y(6,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT,y(12,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT,y(18,:),'.m','MarkerSize',12)  % magenta dotted line
hold on
plot(MLAT,y(23,:),'.b','MarkerSize',12)
hold on
plot(MLAT,y(57,:),'--k','LineWidth',2)
hold on 
plot(MLAT,y(145,:),'-k','LineWidth',2)
hold on
plot(x1,z1,'--k','LineWidth',1)
hold on
plot(x2,z1,'--k','LineWidth',1)
%legend('0.5 hrs','2.5 hrs','5.5 hrs','8.5 hrs','11 hrs','28 hrs','72 hrs')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('N_{H^+} (cm^{-3})','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-60,60],'XTick',[-60:20:60]);
set(gca,'YMinorTick','on');
set(gca,'YScale','log','Ylim',[0.1,1e4],'YTick',[1e-1,1e0,1e1,1e2,1e3,1e4]);
text(-54,0.5,'(a)','FontSize',18)

% Tpr
y=TprH;
z1=logspace(3,5,121);
subplot(3,1,2)
plot(MLAT,y(2,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT,y(6,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT,y(12,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT,y(18,:),'.m','MarkerSize',12)  % magenta dotted line
hold on
plot(MLAT,y(23,:),'.b','MarkerSize',12)
hold on
plot(MLAT,y(57,:),'--k','LineWidth',2)
hold on 
plot(MLAT,y(145,:),'-k','LineWidth',2)
hold on
plot(x1,z1,'--k','LineWidth',1)
hold on
plot(x2,z1,'--k','LineWidth',1)
%legend('0.5 hrs','2.5 hrs','5.5 hrs','8.5 hrs','11 hrs','28 hrs','72 hrs')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-60,60],'XTick',[-60:20:60]);
ylabel('TH^+_{//} (K)','fontsize',20)
set(gca,'YScale','log','Ylim',[1000,1e5],'YTick',[1e3,1e4,1e5]);
set(gca,'YMinorTick','on');
text(-54,1800,'(b)','FontSize',18)

% Tpp
y=TppH;
z1=logspace(2,5,121);
subplot(3,1,3)
plot(MLAT,y(2,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT,y(6,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT,y(12,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT,y(18,:),'.m','MarkerSize',12)  % magenta dotted line
hold on
plot(MLAT,y(23,:),'.b','MarkerSize',12)
hold on
plot(MLAT,y(57,:),'--k','LineWidth',2)
hold on 
plot(MLAT,y(145,:),'-k','LineWidth',2)
hold on
plot(x1,z1,'--k','LineWidth',1)
hold on
plot(x2,z1,'--k','LineWidth',1)
legend('0.5','2.5','5.5','8.5','11','28','72 hrs')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-60,60],'XTick',[-60:20:60]);
ylabel('TH^+_{\perp} (K)','fontsize',20)
set(gca,'YScale','log','Ylim',[100,1e5],'YTick',[1e2,1e3,1e4,1e5]);
set(gca,'YMinorTick','on');
text(-54,200,'(c)','FontSize',18)

