close all
clear all
load Neq_GSK_Time.dat
load L_time_forward.dat

D=L_time_forward;
% equatorial density in cm^-3
den=Neq_GSK_Time;

z=size(D(:,1),1);
% start from UT=1.3 h  
L=D(1:z,2);   % L shell with time interval 30 min

L=L';

nstep=15;
UT0=7.0;   % start at UT=7 h

t=[0.0:0.5:7.0];
t=t';
UT=[7.0:0.5:14.0];
UT=UT';

NO=den(:,2);
NH=den(:,3);
NHe=den(:,4);
Ne=den(:,5);

x1=NO.*1.0e4;
x2=NHe.*10;

% density varies with L^(-4)
for q=1:z;
    x3(q)=(L(1)/L(q))^4;
end
x3=x3';
x4=x3.*NO(1)*1.0e4;
x5=x3.*NH(1);
x6=x3.*NHe(1)*10;

%   figure density
subplot(1,2,2)
plot(L(1:15),x1(1:15),'--b','LineWidth',3)
hold on
plot(L(1:15),NH(1:15),'-r','LineWidth',3)
hold on
plot(L(1:15),x2(1:15),'--g','LineWidth',3)
hold on
legend('NO^+ X 10^4','NH^+','NHe^+ X 10')
plot(L(1:15),x4(1:15),'.k','LineWidth',3,'MarkerSize',15)
hold on
plot(L(1:15),x5(1:15),'.k','LineWidth',3,'MarkerSize',15)
hold on
plot(L(1:15),x6(1:15),'.k','LineWidth',3,'MarkerSize',15)
hold on
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('n_{eq} (cm^{-3})','fontsize',20)
xlabel('L (R_E)','fontsize',20)
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on','Yscale','log');
text(5.1,1.45,'(b)','Fontsize',18)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% potential energy difference %%%%%%%%%%%%%%%%%%%%

clear all

load GRID_GSK_Time.dat
load EFD_GSK_Time.dat

load Neq_GSK_Time.dat
load L_time_forward.dat

D=L_time_forward;
% equatorial density in cm^-3
den=Neq_GSK_Time;

z=size(D(:,1));
% start from UT=1.3 h  
L=D(1:z,2);   % L shell with time interval 30 min

L=L';

nstep=15;
UT0=7.0;   % start at UT=1.3 h

t=[0.0:0.5:7.0];
t=t';
UT=[7.0:0.5:14.0];
UT=UT';

nc=281;
nstep=15;

GRID=GRID_GSK_Time;
Re=6371.2e3;    %m
num=nc-1;
x=num/2+1;

% radial distance in Re
rr=reshape(GRID(:,1),nc,nstep);
rr=rr';

% altitude in km
ALT=reshape(GRID(:,2),nc,nstep);
ALT=ALT';
% Geomagnetic latitude in degree
MLAT=reshape(GRID(:,3),nc,nstep);
MLAT=MLAT';
% magnitude of magnetic field in Tesla
bfd=reshape(GRID(:,4),nc,nstep);
bfd=bfd';
% arc length in Re
sg=reshape(GRID(:,5),nc,nstep);
sg=sg';
%gravitational acceleration in Re/s^2
gm=reshape(GRID(:,6),nc,nstep);
gm=gm';
gm=gm.*Re;   %  in units of m/s^2;

EFD=EFD_GSK_Time;

% electric field
efield=reshape(EFD(:,1),nc,nstep);
efield=efield';
% efield=efield.*1e+7;

% electric potential
% electric potential in V
poten(1:nstep,1:nc)=0.0;
for j=1:nstep;
    for i=2:nc;
        poten(j,i)=poten(j,i-1)-0.5*(efield(j,i)+efield(j,i-1))*(sg(j,i)-sg(j,i-1))*Re;
    end
end

for j=1:nstep;
    temp=poten(j,x);
    for i=1:nc;
        poten(j,i)=poten(j,i)-temp;
    end
end

% gravitational potential in m^2/s^2
gpoten(1:nstep,1:nc)=0.0;
for j=1:nstep;
for i=2:nc;
    gpoten(j,i)=gpoten(j,i-1)-0.5*(gm(j,i)+gm(j,i-1))*(sg(j,i)-sg(j,i-1))*Re;
end
end

mH=1.67e-27;   % kg
mO=16.0*mH;
mHe=4.0*mH;
me=9.11e-31;
q=1.6e-19;   % electric charge

GO=gpoten.*mO/q;   %  gravitational potential energy in eV, assuming GO=0 at 800km
GH=gpoten.*mH/q;
GHe=gpoten.*mHe/q;

% electric potential energy in eV at 800km, assuming EP=0 at equator
for j=1:nstep;
    EP(j)=0.5*(poten(j,1)+poten(j,nc));
end
% potential energy difference between equator and 800 km in eV
for j=1:nstep;
    dWO(j)=GO(j,x)-EP(j);
    dWH(j)=GH(j,x)-EP(j);
    dWHe(j)=GHe(j,x)-EP(j);
end
% potential energy difference between equator and 800 km in northern
% hemisphere
for j=1:nstep;
    dWOn(j)=GO(j,x)-poten(j,1);
    dWHn(j)=GH(j,x)-poten(j,1);
    dWHen(j)=GHe(j,x)-poten(j,1);
end

% potential energy difference between equator and 800 km in southern
% hemisphere
for j=1:nstep;
    dWOs(j)=GO(j,x)-poten(j,nc);
    dWHs(j)=GH(j,x)-poten(j,nc);
    dWHes(j)=GHe(j,x)-poten(j,nc);
end
subplot(1,2,1)
plot(L(1:15),dWO(1:15),'--b','LineWidth',3)
hold on
plot(L(1:15),dWH(1:15),'-r','LineWidth',3)
hold on
plot(L(1:15),dWHe(1:15),'--g','LineWidth',3)
hold on
legend('O^+ ','H^+','He^+')

set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('\Phi_{eq}-\Phi_{800km} (eV)','fontsize',20)
xlabel('L (R_E)','fontsize',20)
set(gca,'XMinorTick','on');
set(gca,'YMinorTick','on');
text(5.1,-2.7,'(a)','Fontsize',18)
