clear all
load Den_GSK_Time.dat
load Vel_GSK_Time.dat
load Tpr_GSK_Time.dat
load Tpp_GSK_Time.dat
load GRID_GSK_Time.dat
load EFD_GSK_Time.dat

nc=101;
nstep=15;

t=[0.0:0.5:7.0];
t=t';
UT=[7.0:0.5:14.0];
UT=UT';
GRID=GRID_GSK_Time;

% radial distance in Re
rr=reshape(GRID(:,1),nc,nstep);
rr=rr';

% altitude in km
ALT=reshape(GRID(:,2),nc,nstep);
ALT=ALT';
% Geomagnetic latitude in degree
MLAT=reshape(GRID(:,3),nc,nstep);
MLAT=MLAT';
% magnitude of magnetic field in Tesla
bfd=reshape(GRID(:,4),nc,nstep);
bfd=bfd';
% arc length in Re
sg=reshape(GRID(:,5),nc,nstep);
sg=sg';


Den=Den_GSK_Time;
Vel=Vel_GSK_Time;
Tpr=Tpr_GSK_Time;
Tpp=Tpp_GSK_Time;
EFD=EFD_GSK_Time;

% density in cm^-3
NO=reshape(Den(:,1),nc,nstep);
NO=NO';

NH=reshape(Den(:,2),nc,nstep);
NH=NH';

NHe=reshape(Den(:,3),nc,nstep);
NHe=NHe';

Ne=reshape(Den(:,4),nc,nstep);
Ne=Ne';

% Parallel temperature 
TprO=reshape(Tpr(:,1),nc,nstep);
TprO=TprO';

TprH=reshape(Tpr(:,2),nc,nstep);
TprH=TprH';

TprHe=reshape(Tpr(:,3),nc,nstep);
TprHe=TprHe';

Tpre=reshape(Tpr(:,4),nc,nstep);
Tpre=Tpre';

% Perpendicular temperature 
TppO=reshape(Tpp(:,1),nc,nstep);
TppO=TppO';

TppH=reshape(Tpp(:,2),nc,nstep);
TppH=TppH';

TppHe=reshape(Tpp(:,3),nc,nstep);
TppHe=TppHe';

Tppe=reshape(Tpp(:,4),nc,nstep);
Tppe=Tppe';

% velocity in m/s
VO=reshape(Vel(:,1),nc,nstep);
VO=VO';

VH=reshape(Vel(:,2),nc,nstep);
VH=VH';

VHe=reshape(Vel(:,3),nc,nstep);
VHe=VHe';

Ve=reshape(Vel(:,4),nc,nstep);
Ve=Ve';

% electric field
efield=reshape(EFD(:,1),nc,nstep);
efield=efield';
efield=efield.*1e+7;
% electric potential
poten=reshape(EFD(:,2),nc,nstep);
poten=poten';
poten=poten.*1e7;

mH=1.67e-27;   % kg
mO=16.0*mH;
mHe=4.0*mH;
me=9.11e-31;

kb=1.38e-23;    % m^2 kg s^-2 K^-1

tempO=2.0*kb/mO;
tempH=2.0*kb/mH;
tempHe=2.0*kb/mHe;
tempe=2.0*kb/me;

for q=1:nstep;
    for p=1:nc;
        VOs(q,p)=sqrt(tempO*TprO(q,p));
        VHs(q,p)=sqrt(tempH*TprH(q,p));
        VHes(q,p)=sqrt(tempHe*TprHe(q,p));
        Ves(q,p)=sqrt(tempe*Tpre(q,p));
    end
end

for q=1:nstep;
    for p=1:nc;
        xO(q,p)=VOs(q,p)-abs(VO(q,p));
        xH(q,p)=VHs(q,p)-abs(VH(q,p));
        xHe(q,p)=VHes(q,p)-abs(VHe(q,p));
        xe(q,p)=Ves(q,p)-abs(Ve(q,p));
    end
end

y=VO;
subplot(2,2,1)
plot(MLAT(1,:),y(1,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT(4,:),y(4,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT(7,:),y(7,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT(10,:),y(10,:),'.m','MarkerSize',10)  % magenta dotted line
hold on
plot(MLAT(13,:),y(13,:),'--k','LineWidth',2)
hold on
plot(MLAT(15,:),y(15,:),'-k','LineWidth',2)
hold on
legend('0 hrs','1.5 hrs','3 hrs','4.5 hrs','6 hrs','7 hrs')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('V_{O^+} (m/s)','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-70,70],'XTick',[-60:20:60]);
set(gca,'YMinorTick','on','Ylim',[-1500,1500]);
text(61,-1200,'(a)','FontSize',18)

y=VH;
subplot(2,2,2)
plot(MLAT(1,:),y(1,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT(4,:),y(4,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT(7,:),y(7,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT(10,:),y(10,:),'.m','MarkerSize',10)  % magenta dotted line
hold on
plot(MLAT(13,:),y(13,:),'--k','LineWidth',2)
hold on
plot(MLAT(15,:),y(15,:),'-k','LineWidth',2)
hold on
legend('0 hrs','1.5 hrs','3 hrs','4.5 hrs','6 hrs','7 hrs')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('V_{H^+} (m/s)','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-70,70],'XTick',[-60:20:60]);
set(gca,'YMinorTick','on','Ylim',[-6000,6000]);
text(61,-4800,'(b)','FontSize',18)

y=VHe;
subplot(2,2,3)
plot(MLAT(1,:),y(1,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT(4,:),y(4,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT(7,:),y(7,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT(10,:),y(10,:),'.m','MarkerSize',10)  % magenta dotted line
hold on
plot(MLAT(13,:),y(13,:),'--k','LineWidth',2)
hold on
plot(MLAT(15,:),y(15,:),'-k','LineWidth',2)
hold on
legend('0 hrs','1.5 hrs','3 hrs','4.5 hrs','6 hrs','7 hrs')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('V_{He^+} (m/s)','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-70,70],'XTick',[-60:20:60]);
set(gca,'YMinorTick','on','Ylim',[-2500,2500]);
text(61,-2000,'(c)','FontSize',18)

y=Ve;
subplot(2,2,4)
plot(MLAT(1,:),y(1,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT(4,:),y(4,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT(7,:),y(7,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT(10,:),y(10,:),'.m','MarkerSize',10)  % magenta dotted line
hold on
plot(MLAT(13,:),y(13,:),'--k','LineWidth',2)
hold on
plot(MLAT(15,:),y(15,:),'-k','LineWidth',2)
hold on
legend('L=5.5','L=5.89','L=6.14','L=6.52','L=7.41','L=8.73')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('V_{e} (m/s)','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-70,70],'XTick',[-60:20:60]);
set(gca,'YMinorTick','on','Ylim',[-3000,3000]);
text(61,-2400,'(d)','FontSize',18)