clear all
load Den_GSK_Time.dat
load Vel_GSK_Time.dat
load Tpr_GSK_Time.dat
load Tpp_GSK_Time.dat
load GRID_GSK_Time.dat
load EFD_GSK_Time.dat
load denO_GSK_Time.dat

nc=281;
nstep=15;
num=280;

t=[0.0:0.5:7.0];
t=t';
UT=[7.0:0.5:14.0];
UT=UT';
GRID=GRID_GSK_Time;
Re=6371.2e3;    %m

% denO is not interpolated
DD=denO_GSK_Time;
ALT2=reshape(DD(:,1),num,nstep);
ALT2=ALT2';
MLAT2=reshape(DD(:,2),num,nstep);
MLAT2=MLAT2';
denO2=reshape(DD(:,3),num,nstep);
denO2=denO2';

% radial distance in Re
rr=reshape(GRID(:,1),nc,nstep);
rr=rr';

% altitude in km
ALT=reshape(GRID(:,2),nc,nstep);
ALT=ALT';
% Geomagnetic latitude in degree
MLAT=reshape(GRID(:,3),nc,nstep);
MLAT=MLAT';
% magnitude of magnetic field in Tesla
bfd=reshape(GRID(:,4),nc,nstep);
bfd=bfd';
% arc length in Re
sg=reshape(GRID(:,5),nc,nstep);
sg=sg';
%gravitational acceleration in Re/s^2
gm=reshape(GRID(:,6),nc,nstep);
gm=gm';
gm=gm.*Re;   %  in units of m/s^2;

Den=Den_GSK_Time;
Vel=Vel_GSK_Time;
Tpr=Tpr_GSK_Time;
Tpp=Tpp_GSK_Time;
EFD=EFD_GSK_Time;

% density in cm^-3
NO=reshape(Den(:,1),nc,nstep);
NO=NO';

NH=reshape(Den(:,2),nc,nstep);
NH=NH';

NHe=reshape(Den(:,3),nc,nstep);
NHe=NHe';

Ne=reshape(Den(:,4),nc,nstep);
Ne=Ne';

% Parallel temperature 
TprO=reshape(Tpr(:,1),nc,nstep);
TprO=TprO';

TprH=reshape(Tpr(:,2),nc,nstep);
TprH=TprH';

TprHe=reshape(Tpr(:,3),nc,nstep);
TprHe=TprHe';

Tpre=reshape(Tpr(:,4),nc,nstep);
Tpre=Tpre';

% Perpendicular temperature 
TppO=reshape(Tpp(:,1),nc,nstep);
TppO=TppO';

TppH=reshape(Tpp(:,2),nc,nstep);
TppH=TppH';

TppHe=reshape(Tpp(:,3),nc,nstep);
TppHe=TppHe';

Tppe=reshape(Tpp(:,4),nc,nstep);
Tppe=Tppe';

% velocity in m/s
VO=reshape(Vel(:,1),nc,nstep);
VO=VO';

VH=reshape(Vel(:,2),nc,nstep);
VH=VH';

VHe=reshape(Vel(:,3),nc,nstep);
VHe=VHe';

Ve=reshape(Vel(:,4),nc,nstep);
Ve=Ve';

mH=1.67e-27;   % kg
mO=16.0*mH;
mHe=4.0*mH;
me=9.11e-31;

mass_distr=NO.*mO+NH.*mH+NHe.*mHe;

y=denO2;
subplot(2,2,1)
plot(MLAT2(1,:),y(1,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT2(4,:),y(4,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT2(7,:),y(7,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT2(10,:),y(10,:),'.m','MarkerSize',10)  % magenta dotted line
hold on
plot(MLAT2(13,:),y(13,:),'--k','LineWidth',2)
hold on
plot(MLAT2(15,:),y(15,:),'-k','LineWidth',2)
hold on
legend('0 hrs','1.5 hrs','3 hrs','4.5 hrs','6 hrs','7 hrs')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('n_{O^+} (cm^{-3})','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-70,70],'XTick',[-60:20:60]);
set(gca,'YMinorTick','on','Yscale','log','Ylim',[1e-4,1e7],'YTick',[1e-4,1e-2,1e0,1e2,1e4,1e6]);
text(-66,1e-3,'(a)','FontSize',18)

y=NH;
subplot(2,2,2)
plot(MLAT(1,:),y(1,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT(4,:),y(4,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT(7,:),y(7,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT(10,:),y(10,:),'.m','MarkerSize',10)  % magenta dotted line
hold on
plot(MLAT(13,:),y(13,:),'--k','LineWidth',2)
hold on
plot(MLAT(15,:),y(15,:),'-k','LineWidth',2)
hold on
legend('0 hrs','1.5 hrs','3 hrs','4.5 hrs','6 hrs','7 hrs')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('n_{H^+} (cm^{-3})','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-70,70],'XTick',[-60:20:60]);
set(gca,'YMinorTick','on','Yscale','log','Ylim',[1e2,1e5],'YTick',[1e2,1e3,1e4,1e5]);
text(61,190,'(b)','FontSize',18)

y=NHe;
subplot(2,2,3)
plot(MLAT(1,:),y(1,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT(4,:),y(4,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT(7,:),y(7,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT(10,:),y(10,:),'.m','MarkerSize',10)  % magenta dotted line
hold on
plot(MLAT(13,:),y(13,:),'--k','LineWidth',2)
hold on
plot(MLAT(15,:),y(15,:),'-k','LineWidth',2)
hold on
legend('0 hrs','1.5 hrs','3 hrs','4.5 hrs','6 hrs','7 hrs')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('n_{He^+} (cm^{-3})','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-70,70],'XTick',[-60:20:60]);
set(gca,'YMinorTick','on','Yscale','log','Ylim',[1e0,1e4],'YTick',[1e0,1e1,1e2,1e3,1e4]);
text(-66,2.4,'(c)','FontSize',18)

y=mass_distr;
subplot(2,2,4)
plot(MLAT(1,:),y(1,:),'-r','LineWidth',2)   % red solid line
hold on
plot(MLAT(4,:),y(4,:),'-.b','LineWidth',2)  % blue dash-dot line
hold on
plot(MLAT(7,:),y(7,:),'--g','LineWidth',2)  % green dashed line
hold on
plot(MLAT(10,:),y(10,:),'.m','MarkerSize',10)  % magenta dotted line
hold on
plot(MLAT(13,:),y(13,:),'--k','LineWidth',2)
hold on
plot(MLAT(15,:),y(15,:),'-k','LineWidth',2)
hold on
legend('L=5.5','L=5.89','L=6.14','L=6.52','L=7.41','L=8.73')
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('\rho (kg cm^{-3})','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-70,70],'XTick',[-60:20:60]);
set(gca,'YMinorTick','on','Yscale','log','Ylim',[1e-25,1e-19],'YTick',[1e-25,1e-23,1e-21,1e-19]);
text(61,4e-25,'(d)','FontSize',18)