!     
! File:   eqedrift.f90
! Calculate the equatorial trajectory of the drifting flux tube 
! due to the corotation Efield and convection Efield.
! The convection E field is E5D Model.
! B field is dipole magnetic field.
! Veq in the 'FLIPPOS.dat' is the velocity due to the convection E field.
!
! Start from the POINT (XGSW_eqe,YGSW_eqe,ZGSW_eqe) ON THE
! MODEL MAGNETOPAUSE OF SHUE ET AL. (JGR-A, V.103, P. 17691, 1998) and
! calculate time backward.
!
! The initial data files for the first run in order to load particles in GSK domain
! are named as 'Dh_INITIAL.dat','FLIPPOS_INITIAL.dat','FLIPDRIFT_INITIAL.dat', and 
! 'GSKDRIFT_INITIAL.dat'.
!
! Use data files 'Dh.dat','FLIPPOS.dat','FLIPDRIFT.dat' and 'GSKDRIFT.dat' to continue 
! run the DyFK model.
! Revised on Jan. 23 2015, Created on June 20, 2012 by Yan Wang
!

PROGRAM main

    USE GRIDPARAM
    implicit none

    real Et(3),Vsx,Vsy,Vsz,Ecr(3),Ecv(3)

    real bfd,Re,Be
    real(8) dh,we0,curt0,Veq,Vcr,L_eqe,V
    real Vs(3)

    real COLAT,XLON,MAGLON
    real tmp1,tmp2,pi,pi2
    real XGEO,YGEO,ZGEO,XGSW,YGSW,ZGSW
    real XSM,YSM,ZSM,MLAT

    Integer i,j,k
    real XMAG_eqe,YMAG_eqe,ZMAG_eqe,MCOLAT,MLON
    real XN_PD,BZIMF,XMGNP,YMGNP,ZMGNP,DIST
    integer ID

    REAL SEC,R_eqe,s0,s,P_c,SEC_start
    Real BLATD,BLONG,GLATD,GLONG,BCOLAT,GCOLAT,alt,ALT1
    Real GLON,XFGEO,YFGEO,ZFGEO,XFMAG,YFMAG,ZFMAG
    Real ZB,XBMAG,YBMAG,ZBMAG,XBMAG0,YBMAG0,ZBMAG0
    Real ZBLATD,ZBCOLAT,dl1,dl2
    Real VGSEX1,VGSEY1,VGSEZ1

    Character(len=10) charac1
    Character(len=12) charac2
    real F107
    integer Dst
    real Kr,Krr,Rar,H,dH_dr,dH_dphi,dP_dr,dP_dphi

    integer step
    integer LNBLNK
    character suff*6
    real  starttime,endtime, temp_vs1,temp_vs2
    real(8) R_s0, ALPHA,THETA
    REAL XGSM_MS,YGSM_MS,ZGSM_MS,XMAG_MS,YMAG_MS,ZMAG_MS,R_MS,MCOLAT_MS

    data Re/6371.2e3/,Be/3.11d-5/,pi/3.1415926/,P_c/1.34217728/,pi2/6.2831852/

      CALL CPU_TIME(starttime)

      open(unit=71,file='Eqepos.dat',status='unknown')
 !     write(71,*) '#        L[Re]       MLON[degree]      MLAT[degree]       XGSM[Re]     YGSM[Re]        ZGSM[Re]         XSM[Re]          YSM[Re]           ZSM[Re]'

      open(UNIT=72,file='EB.dat',status='unknown')
 !     write(72,*) '#    Er(V/m)    Ephi(V/m)     Et(V/m)      B(T)' 

      open(unit=74,file='V.dat',status='unknown')
 !     write(74,*) '#    Vr(m/s)      Vphi(m/s)       Vt(m/s)'

      OPEN(UNIT=47,FILE='Dh_backward.dat',status='unknown')
      OPEN(UNIT=46,FILE='FLIPPOS_backward.dat',status='unknown')

      open(unit=102,file='FLIPDRIFT_backward.dat',status='unknown')
      open(unit=103,file='GSKDRIFT_backward.dat',status='unknown')
	
      dt=4.0
      nstep2=int(7*60*15)      !  24 hour
      we0=0.0d0
      curt0=0.0d0
      alt=1.0+250.0/Re     ! altitude used in FLIP
      zb=1.0+800.0/Re

 !   DEFINE THE UNIVERSAL TIME AND PREPARE THE COORDINATE TRANSFORMATION PARAMETERS
 !   BY INVOKING THE SUBROUTINE RECALC_08

      IYEAR=2001
      IDAY=90
      IHOUR=14
      IMIN=0
      ISEC=0
   
      SEC_start=REAL(IHOUR+IMIN/60.0)
      
      VGSEX=-400.0
      VGSEY=0.0
      VGSEZ=0.0

      CALL RECALC_08 (IYEAR,IDAY,IHOUR,IMIN,ISEC,VGSEX,VGSEY,VGSEZ)

!  Define IMF Bz (nT)  and solar wind dynamic pressure (nPa) to calculate the position of the magentopause
      BZIMF=-10.5
      XN_PD=3.6
!  the radial distance of the subsolar point on the magnetopause (Shue's model)
      R_s0=(10.22+1.29*TANH(0.184*(BZIMF+8.14)))*XN_PD**(-0.15151515)
      ALPHA=(0.58-0.007*BZIMF)*(1.0+0.024*ALOG(XN_PD))
      THETA=34.0*0.01745329
! Define a point on the magnetopause      
      XGSM_MS=R_s0*(2.0/(1.0+COS(THETA)))**ALPHA*COS(THETA)
      YGSM_MS=R_s0*(2.0/(1.0+COS(THETA)))**ALPHA*SIN(THETA)
      ZGSM_MS=0.0
! Find the equatorial piont on the same field line as XGSM_MS, YGSM_MS, ZGSM_MS

      CALL GEOGSW_08(XGEO,YGEO,ZGEO,XGSM_MS,YGSM_MS,ZGSM_MS,-1)
      
      CALL GEOMAG_08(XGEO,YGEO,ZGEO,XMAG_MS,YMAG_MS,ZMAG_MS,1)      

      CALL SPHCAR_08 (R_MS,MCOLAT_MS,MLON,XMAG_MS,YMAG_MS,ZMAG_MS,-1)      
        
!    THE LINE WILL STARTE FROM A  FOOTPOINT (unit Re) in the magentic equtorial plane ON THE MAGNETOPAUSE
      R_eqe=R_MS/((SIN(MCOLAT_MS))**2)
      MCOLAT=90.0*0.01745329

!     CONVERT SPHERICAL COORDS INTO CARTESIAN COORDS  :
      CALL SPHCAR_08 (R_eqe,MCOLAT,MLON,XMAG_eqe,YMAG_eqe,ZMAG_eqe,1)

!     CONVERT GEOMAGNETIC  COORDS INTO Solar Magnetic COORDS  :
      CALL MAGSM_08(XMAG_eqe,YMAG_eqe,ZMAG_eqe,XSM,YSM,ZSM,1)   
   
      CALL GEOMAG_08(XGEO,YGEO,ZGEO,XMAG_eqe,YMAG_eqe,ZMAG_eqe,-1)
      CALL GEOGSW_08(XGEO,YGEO,ZGEO,XGSW,YGSW,ZGSW,1)
     
      !  XLON is the azimuthal angel from noon
      !  XLON, COLAT in the GSW coordinate system
      CALL SPHCAR_08(R_eqe,COLAT,XLON,XGSW,YGSW,ZGSW,-1)     

      !  MAG COORDS FOR POINT AT ALTITUDE 800 Km   !  in unit of rad
      ZBCOLAT=ASIN(SQRT(ZB/R_eqe))
      !     CONVERT SPHERICAL COORDS INTO CARTESIAN COORDS  :
      CALL SPHCAR_08 (ZB,ZBCOLAT,0.0,XBMAG0,YBMAG0,ZBMAG0,1) 
      
! Define Kp to calculate the electric field at the equator
      Kp=5.0

     do step=1,nstep2

            SEC=SEC_start-(step-1)*dt/3600.0
            
      !  COROTATION E - unit V/m  in cylindrical coords  at the magnetic equator
            Ecr(1)=-92.0*1e+3/(R_eqe**2*Re)
            Ecr(2)=0.0d0  
            Ecr(3)=0.0d0

      !  CONVECTION E - unit V/m  in cylindrical coords at the magnetic equator
      !  XLON is the angle from the noon calculated in GSM 
            Kr=Kp/(1.0+0.1*Kp)
            Krr=1.0+0.3*Kr
            Rar=9.8+1.4*cos(XLON)-(0.9-0.3*cos(XLON))*Kr
            H=1.0/(1.0+(0.8*Rar/R_eqe)**8)

            dH_dr=P_c*(H**2)*(Rar**8)/R_eqe**9
            dH_dphi=P_c*(H**2)*(Rar**7)*(1.4+0.3*Kr)*sin(XLON)/R_eqe**8
            tmp1=3.0-R_eqe*(0.8*sin(XLON)+0.2*cos(XLON))

            dP_dr=tmp1*Krr*dH_dr-(0.8*sin(XLON)+0.2*cos(XLON))*Krr*H
            dP_dphi=tmp1*Krr*dH_dphi+R_eqe*(0.2*sin(XLON)-0.8*cos(XLON))*Krr*H
            tmp2=-1.0e+3/Re

            Ecv(1)=tmp2*dP_dr
            Ecv(2)=tmp2*dP_dphi/R_eqe 
            Ecv(3)=0.0
      !  Total Electric field
            Et(1)=Ecr(1)+Ecv(1)
            Et(2)=Ecr(2)+Ecv(2)
            Et(3)=Ecr(3)+Ecv(3)

        !  magnetic field (Tesla)
            bfd=Be/R_eqe**3
        !  componets of velocities under total E
            Vs(1)=Et(2)/(bfd*Re)       ! radial velocity in Re/s
            Vs(2)=-Et(1)/(bfd*R_eqe*Re)      ! angular velocity in rad/s
            Vs(3)=0.0d0

       !   Veq is the radial velocity by the convection E field, 
       !    unit m/s, type -- real(8)
            Veq=Ecv(2)/bfd
            Vcr=-Ecv(1)/bfd 
            
            MAGLON=MLON/0.01745329
            MLAT=90.0d0-MCOLAT/0.01745329

            BCOLAT=ASIN(sqrt(alt/R_eqe))    !   in unit of rad
            !     CONVERT SPHERICAL COORDS INTO CARTESIAN COORDS  :
            CALL SPHCAR_08 (alt,BCOLAT,MLON,XFMAG,YFMAG,ZFMAG,1)
            !     CONVERT MAG COORDS INTO GEOGRAHIC COORDS  :
            CALL GEOMAG_08 (XFGEO,YFGEO,ZFGEO,XFMAG,YFMAG,ZFMAG,-1)
            !     CONVERT GEO COORDS INTO SPHERICAL COORDS  :
            CALL SPHCAR_08 (ALT1,GCOLAT,GLON,XFGEO,YFGEO,ZFGEO,-1)

            GLATD=90.0-GCOLAT*57.2957795
            GLONG=GLON*57.2957795

            temp_vs1=Et(2)/bfd   ! in m/s
            temp_vs2=-Et(1)/bfd   ! in m/s

            IF(step.ge. 1 .and. step.le.(nstep2-4)) THEN
                write(71,*) nstep2-3-step,R_eqe,MAGLON,MLAT,XGSW,YGSW,ZGSW,XSM,YSM,ZSM
        
                write(72,*) nstep2-3-step,Ecv(1),Ecv(2),sqrt(Ecv(1)**2+Ecv(2)**2),bfd

                write(74,*) nstep2-3-step,Veq,Vcr,sqrt(Veq**2+Vcr**2), &
                            temp_vs1,temp_vs2,sqrt(temp_vs1**2+temp_vs2**2)
            ENDIF

            L_eqe=R_eqe

          if(step .ge. 1 .and. mod((step-1),5).eq.0) then         
              WRITE(46,*) SEC, L_eqe, real(MAGLON)
  
              V=Veq*100.0
              WRITE(102,*) V    !  unit - cm/s
           endif

           
            IF(step.ge. 1 .and. step.le.(nstep2-4)) WRITE(103,*) we0,Veq,Vcr,curt0,L_eqe
     !       IF(step.ge. 1171) WRITE(103,*) we0,Veq,Vcr,curt0,L_eqe       !  record the parameters after drifting 1.3 hours

            ! the perpendicular velocity at alt=800km multiplied by time
            dl2=abs(dt*Vs(1)*zb**1.5/(R_eqe*sqrt(4.0*R_eqe-3.0*zb)))

            ! update the new L shell and longitude, Time step is backward 
            XLON=XLON-dt*Vs(2)
       
            IF (XLON .lt. 0.0) XLON=XLON+pi2
            IF (XLON .gt. pi2) XLON=XLON-pi2
            
            R_eqe=R_eqe-dt*Vs(1)          
            IF(R_eqe.gt.20.0) THEN
                write(*,*) 'L shell larger than 20 Re'
                stop
            ENDIF


            IHOUR=int(SEC_start-step*dt/3600.0)
            IMIN=int((SEC_start-step*dt/3600.0-IHOUR)*60)

            CALL RECALC_08 (IYEAR,IDAY,IHOUR,IMIN,ISEC,VGSEX,VGSEY,VGSEZ)            
                         
             !  MAG COORDS FOR POINT AT ALTITUDE 800 Km  at new L-shell
             ZBCOLAT=ASIN(SQRT(ZB/R_eqe))    !   in unit of rad

             !  CONVERT SPHERICAL COORDS INTO CARTESIAN COORDS  :
             CALL SPHCAR_08 (ZB,ZBCOLAT,0.0,XBMAG,YBMAG,ZBMAG,1) 
             ! the distance between the points at 800 km on the present field line and the next field line
              dl1=(XBMAG-XBMAG0)**2+(YBMAG-YBMAG0)**2+(ZBMAG-ZBMAG0)**2

      !  dh --type  real(8)
            dh=sqrt(abs(dl1-dl2**2))

            if(Vs(1).lt.0.0d0) dh=0.0d0
           
            if(step.ge. 1 .and. step.le.(nstep2-5)) write(47,*) dh  
    
            XBMAG0=XBMAG
            YBMAG0=YBMAG
            ZBMAG0=ZBMAG

            CALL SPHCAR_08 (R_eqe,COLAT,XLON,XGSW,YGSW,ZGSW,1)
       !   TRANSFORM GEOGRAPHICAL GEOCENTRIC COORDS INTO SOLAR WIND MAGNETOSPHERIC ONES:
	    CALL GEOGSW_08 (XGEO,YGEO,ZGEO,XGSW,YGSW,ZGSW,-1)  
       !     CONVERT MAG COORDS INTO GEO :
	    CALL GEOMAG_08 (XGEO,YGEO,ZGEO,XMAG_eqe,YMAG_eqe,ZMAG_eqe,1)
            CALL SPHCAR_08 (R_eqe,MCOLAT,MLON,XMAG_eqe,YMAG_eqe,ZMAG_eqe,-1)

       !     CONVERT GEOMAGNETIC  COORDS INTO Solar Magnetic COORDS  :
            CALL MAGSM_08(XMAG_eqe,YMAG_eqe,ZMAG_eqe,XSM,YSM,ZSM,1)   

    enddo

       CLOSE(71)
       CLOSE(72)
       CLOSE(74)
       CLOSE(46)
       CLOSE(47)
       CLOSE(48)
       
       CLOSE(102)
       CLOSE(103)
       CLOSE(104)

     ! need to check the parameter n and m in the subroutine
       CALL RW_FILE()
     ! need to check IYEAR, IDAY, IHOUR 
       CALL MS_POSITION(BZIMF,XN_PD)

       
       CALL CPU_TIME(endtime)
       print *, 'it took t=', (endtime-starttime)/60.0, 'minutes'
       print *, 'L_eqe=', L_eqe

  end program

!     
! File:   grid.f90
! Author: yan
!
! Created on August 1, 2012, 3:30 PM
!
!**********************************************************************
!**********************************************************************
!  Rountine to calculate q-coordinate along the field line
!  
!  Input:   num - number of grids on the field line
!           Req - L-shell or equatorial radial distance of field line
!           Z   - array of altitude of the grids, from FLIP routine
!           scalg - scale factor in distributing grids
!           jgn - grid index of GSK lower boundary in FLIP zone
!
!  Output:  qval - array of q values of the grids on the field line
!
!  Written by J Tu 1/27/10
!**********************************************************************
subroutine qvalue(num,Req,qval)
    implicit none

    integer num,jbn,j,pts
    real Req,scalg,qval(num+1),rr,GLL,scalk,scx,Re,qmax,dx

    data Re/6371.2d3/ !Re in m
    
    scalg=0.0001

    rr=1.0d0+1.0d3*800.0/Re
    GLL=acos(sqrt(rr/Req))
    qmax=sin(GLL)/rr**2

    pts=num/2+1
    SCALK=1.0/SINH(scalg*qmax)

    qval(num/2+1)=0.0d0
    do j = 1, num/2
        DX=1.0d0-float((J-1))/float((PTS-1))
!...    qval=the dipole coord  determined from -- sinh(kq)=dx
        SCX=DX/SCALK
        qval(J) = LOG(SCX+SQRT(SCX**2+1.0d0))/scalg
        qval(num+2-J)=-qval(J)
    enddo

end subroutine
!**********************************************************************
!**********************************************************************
!  Rountine to calculate (r, lat) for the grids on a field line
!  
!  Input:   Req - L-shell or equatorial radial distance of field line
!
!  Written by J Tu 1/27/10 
!**********************************************************************
subroutine calc_grid(Req,smax)
    implicit none

    integer,parameter:: num=120
    real,dimension(num+1):: rr,GLL,bfd,qval,sg,area,dA,mirrf,gm
    real,dimension(num+1):: c_vol,vol,alt,ods
    real,dimension(num+1,2):: cf
    integer nst,LNBLNK,j
    real Req,d, e, y, tem, d1, por, x, sxh, volfunc
    real x0,x1,x2,y0,y1,z0,z1,Re,sg0,gme,Be,A0,cc,dd
    real dtg,Veq,Veq2
    real smax

! Earth's mass Me = 5.9742e24 kg; G const = 6.6726e-11 m^3 kg^-1 s^-2
! gme=2*G*Me/Re^3
    data por/0.33333333333333d0/,Re/6371.2d3/,gme/-3.0827654d-6/
    data Be/3.11d-5/,A0/0.01d0/,cc/0.288675134595d0/,dd/1.732050808d0/

    call qvalue(num,Req,qval)
    
    rr(num/2+1)=Req
    GLL(num/2+1)=0.0d0
    bfd(num/2+1)=Be/Req**3

    do j=1, num/2
      d=1.d0/(Req*qval(j)*qval(j))
      e=-1.d0/(qval(j)*qval(j))
      d1=d**2/2.d0
      tem=sqrt(d1*d1-2.37037037037d0*e*e*e)
      y=(d1+tem)**por-(tem-d1)**por

      ! rr - radial distance in unit of Re
      ! GLL - magnetic latitude (in rad)
      rr(j)=(sqrt(2.d0*sqrt(y*y-4.d0*e)-y)-sqrt(y))/2.d0
      GLL(j)=asin(qval(j)*rr(j)*rr(j))

      x=sin(GLL(j))
      sxh=sqrt(1.d0+3.d0*x*x)

      rr(num+2-j)=rr(j)
      GLL(num+2-j)=-GLL(j)

!     magnetic field (Tesla)
      bfd(j)=Be/rr(j)**3*sxh
      bfd(num+2-j)=bfd(j)
    enddo

    x=sin(GLL(1))
    sxh=sqrt(1.d0+3.d0*x*x)
    sg0=Req*(x/2.d0*sxh+cc*log(dd*x+sxh))    

    ! arc length (Re) from N->S. sg=0 at northern boundary
    sg(1)=0.0d0
    do j=2,num+1
      x=sin(GLL(j))
      sxh=sqrt(1.d0+3.d0*x*x)

      sg(j)=sg0-Req*(x/2.d0*sxh+cc*log(dd*x+sxh))
    enddo
    smax=sg(num+1)

end  subroutine




